@@ -427,7 +427,9 @@ class Machine(MachineBase):
         self.run("python3 -m venv app")
         env_dir = "/home/gaea/app"
         run_dir = f"{env_dir}/run"
+        self.run(f"mkdir {run_dir}")
         self.run(f"{self.runinenv} app pip install {package}")
+        self.user = "root"
         with self.supervisor(package) as config:
             config["program:app"] = {
                 "autostart": "true",
